import * as React from "react";
import {observer} from "mobx-react-lite";
import {Schedule, ShiftModel} from "../../../stores/ShiftStore";
import {t} from "@lingui/macro";
import {SelectField} from "@rx-suite/ui";

export const EveryField: React.FunctionComponent<{ shift: ShiftModel, schedule: Schedule, scheduleIndex: number, readOnly?: boolean }> = observer(({
                                                                                                                                                       shift,
                                                                                                                                                       schedule,
                                                                                                                                                       scheduleIndex,
                                                                                                                                                       readOnly
                                                                                                                                                   }) => {
    const name = `shift_schedules[${scheduleIndex}].recurrence_rule.every`;
    const pluralInterval = schedule.recurrence_rule.interval !== 1;
    return (
        <SelectField
            onChange={(_name, value) => {
                shift.handleScheduleChange(scheduleIndex, {
                    ...shift.viewModel.shift_schedules[scheduleIndex],
                    recurrence_rule: {
                        ...shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule,
                        every: value
                    }
                });
            }}
            value={schedule.recurrence_rule.every}
            options={[
                {label: pluralInterval ? t`Days` : t`Day`, value: 'day'},
                {label: pluralInterval ? t`Weeks` : t`Week`, value: 'week'},
                {label: pluralInterval ? t`Months` : t`Month`, value: 'month'},
                {label: pluralInterval ? t`Years` : t`Year`, value: 'year'},
            ]}
            error={!!shift.errors[name]}
            helperText={shift.errors[name]}
            disabled={readOnly}
        />
    );
});