import * as React from "react";
import {observer} from "mobx-react-lite";
import {Schedule, ShiftModel} from "../../../stores/ShiftStore";
import {t} from "@lingui/macro";
import {InputField} from "@rx-suite/ui";

export const IntervalField: React.FunctionComponent<{ shift: ShiftModel, schedule: Schedule, scheduleIndex: number, readOnly?: boolean }> = observer(({
                                                                                                                                                          shift,
                                                                                                                                                          schedule,
                                                                                                                                                          scheduleIndex,
                                                                                                                                                          readOnly
                                                                                                                                                      }) => {
    const name = `shift_schedules[${scheduleIndex}].recurrence_rule.interval`;
    return (
        <InputField label={t`Repeat Every`} type={'number'} value={schedule.recurrence_rule.interval || ''}
                    inputProps={{min: 1, step: 1}}
                    name={name}
                    onChange={e => {
                        const value = (e.target.value === '') ? null : Number(e.target.value);
                        shift.handleScheduleChange(scheduleIndex, {
                            ...shift.viewModel.shift_schedules[scheduleIndex],
                            recurrence_rule: {
                                ...shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule,
                                interval: value
                            }
                        });
                    }}
                    error={!!shift.errors[name]}
                    helperText={shift.errors[name]}
                    disabled={readOnly}
        />
    );
});