import {attribute, DataStore, model, Model} from '@rx-suite/data';
import {t} from "@lingui/macro";
import {computed} from "mobx";

@model({
    transportLayer: "/api/calendar_config",
    singleton: true,
    eager: true,
    permissionTarget: "CalendarConfig",
    routingInfo: {
        update: "/calendar_config/edit",
        read: "/calendar_config"
    }
})
export class CalendarConfigModel extends Model {
    @attribute({
        label: t`Day Start`,
        description: "The earliest time to show in the time view"
    })
    start = 7;

    @attribute({
        label: t`Day End`,
        description: "The latest time to show in the time view"
    })
    end = 19;


    @attribute({
        label: t`Include Weekend?`,
        description: "Whether or not the weekend should be incldued on the calendar"
    })
    weekend = false;

    @computed get span() {
        return Math.max(this.viewModel.end - this.viewModel.start, 0)
    }

    @computed get weekConfig() {
        return {
            daynames: [t`Sun`, t`Mon`, t`Tue`, t`Wed`, t`Thu`, t`Fri`, t`Sat`,],
            hourStart: this.viewModel.start,
            hourEnd: this.viewModel.end,
            workweek: !this.viewModel.weekend
        }
    }

    @computed get monthConfig() {
        return {
            daynames: [t`Sun`, t`Mon`, t`Tue`, t`Wed`, t`Thu`, t`Fri`, t`Sat`,],
            workweek: !this.weekend
        }
    }

    constructor() {
        super();
        super.setup();
    }
}

export const CalendarConfigStore = CalendarConfigModel.store as unknown as DataStore<CalendarConfigModel>;
